{%- include "alabaster/about.html" %}

<p>
    <a class="badge" href="https://dev.azure.com/aio-libs/yarl">
        <img alt="https://dev.azure.com/aio-libs/yarl/_apis/build/status/CI?branchName=master"
            src="https://dev.azure.com/aio-libs/yarl/_apis/build/status/CI?branchName=master" />
    </a>
</p>